<?php

declare(strict_types=1);

namespace Drupal\rules_http_client\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Rules HTTP Client settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'rules_http_client_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['rules_http_client.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('rules_http_client.settings');
    $form['logging'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Logging'),
      '#open' => TRUE,
    ];
    $form['logging']['show_responses'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show debug messages'),
      '#description' => $this->t('Show responses in the UI when the request debugging is enabled. Requires the user to have the %view_rules_debug_log_permission permission.', [
        '%view_rules_debug_log_permission' => 'View Rules debug log',
      ]),
      '#default_value' => $config->get('show_responses') ?: FALSE,
    ];
    $form['logging']['max_response_size'] = [
      '#type' => 'number',
      '#min' => 0,
      '#title' => $this->t('Maximum response body size'),
      '#description' => $this->t('The maximum allowed size of the response body to log. Useful when the response can be extremely large.'),
      '#default_value' => $config->get('max_response_size') ?: 10000,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('rules_http_client.settings')
      ->set('show_responses', $form_state->getValue('show_responses'))
      ->set('max_response_size', $form_state->getValue('max_response_size'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
